@@ -9,6 +9,8 @@ use List::Util qw(first);
 use Class::Std::Storable;
 use base qw(SOAP::WSDL::Base);
 
+our $VERSION='2.00_17';
+
 my %types_of    :ATTR(:name<types>      :default<[]>);
 my %message_of  :ATTR(:name<message>    :default<()>);
 my %portType_of :ATTR(:name<portType>   :default<()>);
@@ -43,13 +45,13 @@ BLOCK: {
   }
 }
 
-sub listify {
-    my $data = shift;
-    return if not defined $data;
-    return [ $data ] if not ref $data;
-    return [ $data ] if not ref $data eq 'ARRAY';
-    return $data;
-}
+#sub listify {
+#    my $data = shift;
+#    return if not defined $data;
+#    return [ $data ] if not ref $data;
+#    return [ $data ] if not ref $data eq 'ARRAY';
+#    return $data;
+#}
 
 1;
 
