@@ -2,14 +2,7 @@
 package SOAP::WSDL::Expat::Message2Hash;
 use strict;
 use warnings;
-use XML::Parser::Expat;
-
-sub new {
-    my ($class, $args) = @_;
-    my $self = {};
-    bless $self, $class;
-    return $self;
-}
+use base qw(SOAP::WSDL::Expat::Base);
 
 sub _initialize {
     my ($self, $parser) = @_;
@@ -23,7 +16,7 @@ sub _initialize {
     $self->{ data } = $current;
     
     # use "globals" for speed
-    my ($_prefix, $_localname, $_element, $_method, 
+    my ($_element, $_method, 
         $_class, $_parser, %_attrs) = ();
 
     no strict qw(refs);     
@@ -56,8 +49,6 @@ sub _initialize {
         
         End => sub {        
             $_element = $_[1];
-            ($_prefix, $_localname) = split m{:}xms , $_element;          
-            $_localname ||= $_element;          # for non-prefixed elements            
 
             # This one easily handles ignores for us, too...
             # return if not ref $$list[-1];
@@ -78,42 +69,13 @@ sub _initialize {
     return $parser;
 }
 
-sub parse {
-    eval { 
-        $_[0]->_initialize( XML::Parser::Expat->new( Namespaces => 1 ) )->parse( $_[1] );
-        $_[0]->{ parser }->release();
-    };
-    die $@ if $@;
-    return $_[0]->{ data };     
-}
-
-sub parsefile {
-    eval { 
-        $_[0]->_initialize( XML::Parser::Expat->new( Namespaces => 1 ) )->parsefile( $_[1] );
-        $_[0]->{ parser }->release(); 
-    };
-    die $@, $_[1] if $@;
-    return $_[0]->{ data };     
-}
-
-# SAX-like aliases
-sub parse_string;
-*parse_string = \&parse;
-
-sub parse_file;
-*parse_file = \&parsefile;
-
-sub get_data {
-    return $_[0]->{ data };
-}
-
 1;
 
 =pod
 
 =head1 NAME
 
-SOAP::WSDL::Expat::MessageParser - Convert SOAP messages to custom object trees
+SOAP::WSDL::Expat::Message2Hash - Convert SOAP messages to perl hash refs
 
 =head1 SYNOPSIS
 
@@ -129,19 +91,14 @@ Real fast expat based SOAP message parser.
 
 See L<SOAP::WSDL::Parser> for details.
 
-=head2 Skipping unwanted items
-
-Sometimes there's unneccessary information transported in SOAP messages.
-
-To skip XML nodes (including all child nodes), just edit the type map for 
-the message and set the type map entry to '__SKIP__'. 
-
 =head1 Bugs and Limitations
 
 =over
 
 =item * Ignores all namespaces
 
+=item * Ignores all attributes
+
 =item * Does not handle mixed content
 
 =item * The SOAP header is ignored
