@@ -3,7 +3,7 @@ package SOAP::WSDL::Expat::MessageParser;
 use strict;
 use warnings;
 use SOAP::WSDL::XSD::Typelib::Builtin;
-use XML::Parser::Expat;
+use base qw(SOAP::WSDL::Expat::Base);
 
 sub new {
     my ($class, $args) = @_;
@@ -17,8 +17,8 @@ sub new {
 
 sub class_resolver {
     my $self = shift;
-    $self->{ class_resolver } = shift;
-    return;
+    $self->{ class_resolver } = shift if @_;
+    return $self->{ class_resolver }; 
 }
 
 sub _initialize {
@@ -26,6 +26,7 @@ sub _initialize {
     $self->{ parser } = $parser;
 
     delete $self->{ data };                     # remove potential old results
+    delete $self->{ header };
     
     my $characters;
     #my @characters_from = ();
@@ -48,6 +49,15 @@ sub _initialize {
             },
             1 => sub {
                     $depth++;
+                    if ($_[1] eq 'Body') {
+                        if (exists $self->{ data }) { # there was header data 
+                            $self->{ header } = $self->{ data };
+                            delete $self->{ data };
+                            $list = [];
+                            $path = [];
+                            undef $current;
+                        }
+                    }
                     return;            
             }
         ) 
@@ -123,7 +133,6 @@ sub _initialize {
         Char => $char_handler,
         
         End => sub {
-        
             pop @{ $path };                     # step up in path
        
             if ($skip) {
@@ -165,37 +174,9 @@ sub _initialize {
     return $parser;
 }
 
-sub parse {
-    eval { 
-        $_[0]->_initialize( 
-            XML::Parser::Expat->new(
-                Namespaces => 1
-                )
-            )->parse( $_[1] );
-        $_[0]->{ parser }->release();
-    };
-    $_[0]->{ parser }->xpcroak( $@ ) if $@;
-    return $_[0]->{ data };     
-}
 
-sub parsefile {
-    eval { 
-        $_[0]->_initialize( XML::Parser::Expat->new(Namespaces => 1) )->parsefile( $_[1] ); 
-        $_[0]->{ parser }->release();
-    };
-    die $@, $_[1] if $@;
-    return $_[0]->{ data };     
-}
-
-# SAX-like aliases
-sub parse_string;
-*parse_string = \&parse;
-
-sub parse_file;
-*parse_file = \&parsefile;
-
-sub get_data {
-    return $_[0]->{ data };
+sub get_header {
+    return $_[0]->{ header };
 }
 
 1;
@@ -253,8 +234,8 @@ This module may be used under the same terms as perl itself.
 
  $ID: $
 
- $LastChangedDate: 2007-09-27 21:06:29 +0200 (Don, 27 Sep 2007) $
- $LastChangedRevision: 283 $
+ $LastChangedDate: 2007-10-03 20:46:56 +0200 (Mit, 03 Okt 2007) $
+ $LastChangedRevision: 305 $
  $LastChangedBy: kutterma $
 
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Expat/MessageParser.pm $
