@@ -8,7 +8,7 @@ use base qw(SOAP::WSDL::Expat::MessageParser);
 
 sub parse_start {
     my $self = shift;
-    $self->{ parser } = $_[0]->_initialize( XML::Parser::ExpatNB->new() );
+    $self->{ parser } = $_[0]->_initialize( XML::Parser::ExpatNB->new( Namespaces => 1 ) );
 }
 sub init;
 *init = \&parse_start;
@@ -19,6 +19,7 @@ sub parse_more {
 
 sub parse_done {
     $_[0]->{ parser }->parse_done();
+    $_[0]->{ parser }->release();
 }
 
 1;
@@ -67,8 +68,8 @@ This module may be used under the same terms as perl itself.
 
  $ID: $
 
- $LastChangedDate: 2007-09-10 17:54:52 +0200 (Mon, 10 Sep 2007) $
- $LastChangedRevision: 214 $
+ $LastChangedDate: 2007-10-03 20:46:56 +0200 (Mit, 03 Okt 2007) $
+ $LastChangedRevision: 305 $
  $LastChangedBy: kutterma $
 
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Expat/MessageStreamParser.pm $
