@@ -3,10 +3,12 @@ use strict;
 use Template;
 use Class::Std::Storable;
 
+our $VERSION='2.00_17';
+
 my %tt_of               :ATTR(:get<tt>);
 my %definitions_of      :ATTR(:name<definitions>    :default<()>);
-my %interface_prefix_of :ATTR(:name<interface_prefix> :default<MyInterface>);
-my %typemap_prefix_of   :ATTR(:name<typemap_prefix> :default<MyTypemap>);
+my %interface_prefix_of :ATTR(:name<interface_prefix> :default<MyInterfaces>);
+my %typemap_prefix_of   :ATTR(:name<typemap_prefix> :default<MyTypemaps>);
 my %type_prefix_of      :ATTR(:name<type_prefix>    :default<MyTypes>);
 my %element_prefix_of   :ATTR(:name<element_prefix> :default<MyElements>);
 my %INCLUDE_PATH_of     :ATTR(:name<INCLUDE_PATH>   :default<()>);
