@@ -1,10 +1,9 @@
 package SOAP::WSDL::SOAP::Address;
 use strict;
 use warnings;
+use Class::Std::Storable;
 use base qw(SOAP::WSDL::Base);
-use Class::Std::Fast::Storable;
 
-use version; our $VERSION = qv('2.00.09');
 
 my %location   :ATTR(:name<location> :default<()>);
 1;
\ No newline at end of file
