@@ -2,9 +2,6 @@ package SOAP::WSDL::SOAP::Body;
 use strict;
 use warnings;
 use base qw(SOAP::WSDL::Base);
-use Class::Std::Fast::Storable;
-
-use version; our $VERSION = qv('2.00.09');
 
 my %use_of              :ATTR(:name<use>            :default<q{}>);
 my %namespace_of        :ATTR(:name<namespace>      :default<q{}>);
