@@ -3,7 +3,8 @@ use strict;
 use warnings;
 use Class::Std::Storable;
 use base qw(SOAP::WSDL::Base);
-use Data::Dumper;
+
+our $VERSION='2.00_17';
 
 my %annotation_of   :ATTR(:name<annotation> :default<()>);
 my %simpleType_of   :ATTR(:name<simpleType> :default<()>);
@@ -22,13 +23,6 @@ my %nillable_of     :ATTR(:name<nillable>   :default<()>);
 my %ref_of          :ATTR(:name<ref>        :default<()>);
 my %substitutionGroup_of :ATTR(:name<substitutionGroup> :default<()>);
 
-sub first_type {
-    my $result_ref = $complexType_of{ ident shift };
-    return if not $result_ref;
-    return $result_ref if (not ref $result_ref eq 'ARRAY');
-    return $result_ref->[0];
-}
-
 sub first_simpleType {
     my $result_ref = $simpleType_of{ ident shift };
     return if not $result_ref;
