@@ -22,12 +22,4 @@ BEGIN {
     };
 }
 
-my %length_of           :ATTR(:name<length> :default<()>);
-my %minLength_of        :ATTR(:name<minLength> :default<()>);
-my %maxLength_of        :ATTR(:name<maxLength> :default<()>);
-my %pattern_of          :ATTR(:name<pattern> :default<()>);
-my %enumeration_of      :ATTR(:name<enumeration> :default<()>);
-my %whiteSpace_of       :ATTR(:name<whiteSpace> :default<()>);
-
-
 1;
