@@ -33,29 +33,37 @@ BLOCK: {
     }
 };
 
+# use $_[0] and $_[1] for speed.
+
 sub start_tag {
-    my ($self, $opt, $value) = @_;
-    my $class = ref $self;
-    my $ending = '>';
+    # my ($self, $opt, $value) = @_;
+    my $ending = ($_[1]->{ empty }) ? '/>' : '>';
     my @attr_from = ();
-    my $name = $opt->{ name } || $NAME{$class};
-    $ending = '/>' if ($opt->{ empty });
     
-    if ($opt->{qualified}) {
-        push @attr_from, 'xmlns="' . $self->get_xmlns . '"';
-    }
-    if ($opt->{ nil }) {
-        return q{} if not $NILLABLE{ $class };
+    if ($_[1]->{ nil }) {
+        return q{} if not $NILLABLE{ ref $_[1] };
         push @attr_from, 'xsi:nil="true"';
         $ending = '/>';
     }
-    return join q{ }, "<$name" , @attr_from , $ending;
+    if ($_[1]->{qualified}) {
+        push @attr_from, 'xmlns="' . $_[0]->get_xmlns . '"';
+    }
+    return join q{ }, "<$_[1]->{ name }" , @attr_from , $ending if $_[1]->{ name };
+    return join q{ }, "<$NAME{ ref $_[0]}" , @attr_from , $ending;
 }
 
+# use $_[0] and $_[1] for speed.
+# 
+# read it as:
+#
+# my ($self, $opt)  = @_;
+# my $class = ref $self;
+# return "</$opt->{name}>" if $opt->{name};
+# return "</"$NAME{$class}>";
+#
 sub end_tag {
-    my ($class, $opt) = (ref $_[0], $_[1]);
-    my $name = $opt->{ name } || $NAME{$class};
-    return "</$name>";
+    return "</$_[1]->{name}>" if $_[1]->{name}; 
+    return "</$NAME{ ref $_[0] }>";
 }
 
 1;
